@@ -7,9 +7,7 @@ from sklearn import preprocessing
 import time
 class mlosapi:
     def __init__(self):
-        print("mlOS API Handeler - Session Initialized...")
-
- 
+        self._noneed=""
 
     def getapistatus(self,ismodelokay,model_key):
         if ismodelokay==False:
