@@ -32,7 +32,7 @@ invpsx = imvps.invproc()
 
 class mlosmodel:
     def __init__(self):
-        print("mlOS Deploy Model - Session Initialized...")
+        self._noneed=""
     def getmodelinfo (self,deploytype=None):
         ismodelokay=False
         volumedata='volumedata'
@@ -176,17 +176,12 @@ class mlosmodel:
             }
             inc=inc+1
             lst.append(tmpx)
-        # print(lst)
         return lst
 
 
     def explainmodel(self,model,expinfo,trn_data, smpl, felist, feimp, mtype):
         itype="static"
         try:
-            # print(expinfo)
-            # mtype=  expinfo["mtype"]
-            # if(mtype=="usl"):
-            #     return "__unsupervised__" , "__unsupervised__"
             volumedata='volumedata'
             if("expinfo" in expinfo):
                 volumedata=expinfo['volumedata']
@@ -233,17 +228,8 @@ class mlosmodel:
                 except:
                     pass
                 med =np.array(expinfo["med"]).reshape((1,smpl.shape[1]))
-                print(med)
-                # try:
-                #     if( trn_data!=0):
-                #         med=trn_data
-                # except:
-                #     raise
-                #     pass
-                # print(med)
                 explainer=""
                 if(mtype=="clsify" and algo=="dt"):
-                    print(med)
                     explainer = shap.KernelExplainer(f, med, feature_names = dbset["trn"])
                 elif(mtype=="clsify" and algo =="tree"):
                     explainer = shap.KernelExplainer(f, med, feature_names = dbset["trn"])
@@ -287,7 +273,6 @@ class mlosmodel:
         if ("volumedata" in  modelinfo):
             volumedata=modelinfo["volumedata"]
         fpmodel=modelinfo["model_full_path"]
-        print(fpmodel)
 
         if os.path.exists(fpmodel):
             if (modelinfo["model_ext"]=="bin"): 
@@ -448,6 +433,8 @@ class mlosmodel:
             xTst = tfidf_transformer.transform(tmpVal_)  
             X_test = pd.DataFrame(xTst.toarray())
             return _saveX_test,X_test
+        elif(preselect=='fused'):
+            pass
         elif (preselect   == "vision"):
             # vdir=os.path.join(realtimecall,"vdata") 
             # if(os.path.exists(vdir)==False):
@@ -532,7 +519,6 @@ class mlosmodel:
         y_pred=[]
         y_prob=[]
         y_pred_tmp=[]
-        print(modelinfo)
         dbset= modelinfo["dbset"]
         model_ext = modelinfo["model_ext"]
         formattestdata= modelinfo["formattestdata"]
@@ -626,14 +612,8 @@ class mlosmodel:
             y_pred= np.asarray(y_pred_tmp[0]).ravel()
         else:
             y_pred=y_pred_tmp
-        print("=====")
-        print(y_prob)
-        
-        print("=====")
         tmp_prob=[]
         if(len(y_prob)>1):
-            print("Multi Target")
-            
             for v in y_prob:
                 tmp_prob.append( np.around(v,2).tolist())
         else:
@@ -668,15 +648,12 @@ class mlosmodel:
     def prepare_restored_response(self,y_pred,_saveX_test,modelinfo):
         try:
             colt=modelinfo["dbset"]["tst"]
-            print(colt)
             logfile=modelinfo ["logfile"]
             ts_fn=os.path.join(modelinfo["transformation_dir"],colt[0]+ "+categorical_2_numeric"+ ".pkl")
             mloslgs.logtext(logfile,ts_fn,False) 
             out_con=[]
             reconstrcted_response=[]
             dfx=[]
-            print("=========PRED===========")
-            print(y_pred)
             ln=1
             lnSmpl=len(y_pred)
             for v in y_pred:
@@ -684,12 +661,9 @@ class mlosmodel:
                     ln=len(v)
                 except:
                     pass
-            print(ln)
             _colnames=['predicted']
             _colnames_trns=['predicted_transformed']
-            print("====================")
             if(ln==1):
-                print("Single target")
                 try:
                     if os.path.exists(ts_fn)==True:
 
@@ -703,20 +677,17 @@ class mlosmodel:
                         out_con=invpsx.getinvtransfromed(ts_fn, valx)
                         mloslgs.logtext(logfile,"ecepet",False)
                     except:
-                        print("ERR IN CON")
-                        raise
                         mloslgs.logtext(logfile,"ERRROR",False)
                         out_con=[]
             else:
                 _colnames=[]
                 _colnames_trns=[]
- 
-                print("Multi target")
+
                 out_con=[]
                 colt=modelinfo["dbset"]["tst"]
                 inc=0
                 tdx_ppx=[]
-                print(y_pred)
+
                 for cl in colt:
                     _colnames.append("predicted_"+cl)
                     _colnames_trns.append("predicted_trns_"+cl)
@@ -730,20 +701,15 @@ class mlosmodel:
                         for px_prd in y_pred:
                             y_pred_new.append(int(px_prd[inc]))
                         try:
-                            print(y_pred_new)
                             out_con=invpsx.getinvtransfromed(ts_fn, y_pred_new)
-                            print(out_con)
                             mloslgs.logtext(logfile,out_con,False)
                         except:
-                            print("ERROR INV ER")
-                            raise
                             out_con=y_pred_new
                         tdx_ppx.append(np.array(out_con))
                     else:
                         tdx_ppx.append(np.array(y_pred_new) )
                     inc=inc+1
                 
-                print(tdx_ppx)
                 new_pred_conv=[]
                 for i in range(lnSmpl):
                     _new_vx=[]
@@ -751,17 +717,18 @@ class mlosmodel:
                         _new_vx.append(vx[i])
                     new_pred_conv.append(_new_vx)
 
-                print(new_pred_conv)
                 out_con=np.array(new_pred_conv)
-            print("=========CON===========")
-            print(out_con)
-            print("====================")
+
             if len(out_con)>0:
                 dfx=pd.concat([_saveX_test,pd.DataFrame(y_pred,columns=_colnames ),pd.DataFrame(out_con,columns=_colnames_trns )],axis=1)
                 reconstrcted_response=out_con.tolist()
             else:
                 dfx=pd.concat([_saveX_test,pd.DataFrame(y_pred,columns=_colnames ),pd.DataFrame(y_pred,columns=_colnames_trns )],axis=1)
-                reconstrcted_response=y_pred.tolist()
+                reconstrcted_response=y_pred
+                try:
+                    reconstrcted_response=y_pred.tolist()
+                except:
+                    pass
 
             rows,cols=dfx.shape
             realtime_data_file= modelinfo["realtime_data_file"] 
@@ -790,7 +757,7 @@ class mlosmodel:
                 pass
             return  retval
         except:
-            raise
+            # raise
             # dfx=pd.concat([_saveX_test,pd.DataFrame(y_pred,columns=['predicted'] ),pd.DataFrame(y_pred,columns=['predicted_transformed'] )],axis=1)
             reconstrcted_response=y_pred
             try:
