@@ -1,7 +1,7 @@
 
 import os
 import pickle
-
+import numpy as np
 from sklearn import model_selection
 from sklearn.preprocessing import StandardScaler
 from sklearn import preprocessing
@@ -10,9 +10,9 @@ from sklearn import preprocessing
 
 class invproc:
     def __init__(self):
-        print("mlOS Inverse Process - Session Initialized...")
+        self._noneed=""
     def tst(self,v):
-        print("Tested_inve_process")
+        self.test="yes"
     def logtext(self,fn,msg,vb):
         # valx= str(msg).replace(config._wp,'')
         with open(fn, 'a') as f1:
@@ -85,7 +85,7 @@ class invproc:
                 pickle.dump(scaler, outfile)
             return scaler.transform(data)
         elif(op=="pca"):
-            print("PCA is not implemented")
+            print("PCA does not support.")
             #mllib.mltext("MLP : " + op + ":pca:"  + ntx)
         else:
             #mllib.mltext("MLP : " + op + ":mlpd:"  + ntx)
@@ -108,5 +108,37 @@ class invproc:
             scaler = pickle.load(infile)
         return scaler.inverse_transform(xTst)
 
-    
-
+    def getinvtransfromed2(self,fn,data):
+        scaler =[]
+        with open(fn, 'rb') as infile:  
+            scaler = pickle.load(infile)
+        print("=====CLASSES==========")
+        clslals=scaler.classes_
+        
+        # vvcv=  np.array(data)
+        # print(vvcv)
+        # nwclslals=[]
+        # for cx in clslals:
+        #     nwclslals.append(cx)
+        # print(nwclslals)
+        # inc_classes=scaler.transform(scaler.classes_)
+        # print(inc_classes)
+        # print("=====UNIQUE XTEST==========")
+        # print(np.unique(data))
+        # one_inval=scaler.transform(['_mlos__unseen_'])
+        # print(one_inval)
+        print(data)
+        newxtst=[]
+        for x in  data:
+            v=x[0]
+            # if(np.isnan(v)):
+            #     newxtst.append('_mlos__unseen_')
+            if v in clslals:
+                newxtst.append(str(v))
+            else:
+                newxtst.append('_mlos__unseen_')
+        print("=====UNIQUE NewList==========")
+        
+        trns=scaler.transform(newxtst)
+        print(trns)
+        return  trns
