@@ -2,7 +2,7 @@ import os
 
 class logs:
     def __init__(self):
-        print("mlOS Logs - Session initialized...")
+        self._noneed=""
     def logtext(self,fn,msg,vb):
         # valx= str(msg).replace(config._wp,'')
         with open(fn, 'a') as f1:
